.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

2D Arrays
:::::::::::::::::::::::

Class Periods: 10-12 (including labs)

AP CSA Exam Weighting: 7.5-10%



.. toctree::
   :maxdepth: 3

   topic-8-1-2D-arrays.rst
   topic-8-2-2D-array-loops.rst
   a2dSummary.rst
   Array2dParsonsPractice.rst
   topic-8-4-toggle-problems.rst
   Array2dCodePractice.rst
   freeResponse.rst
   Exercises.rst
   CBLabs.rst

